@@ -120,7 +120,7 @@ Example_StockBrowser::Example_StockBrowser()
   m_refTreeSelection = m_TreeView.get_selection();
   m_refTreeSelection->set_mode(Gtk::SELECTION_SINGLE);
   m_refTreeSelection->signal_changed().connect(
-      SigC::slot(*this, &Example_StockBrowser::on_selection_changed));
+      sigc::mem_fun(*this, &Example_StockBrowser::on_selection_changed));
 
   show_all();
 }
@@ -132,7 +132,7 @@ Example_StockBrowser::~Example_StockBrowser()
 Glib::RefPtr<Gtk::TreeModel> Example_StockBrowser::create_model()
 {
   Glib::RefPtr<Gtk::ListStore> refStore = Gtk::ListStore::create(m_columns);
-  refStore->set_sort_column_id(m_columns.id, Gtk::SORT_ASCENDING);
+  refStore->set_sort_column(m_columns.id, Gtk::SORT_ASCENDING);
 
   // obtain the ids of all stock items
   typedef std::vector<Gtk::StockID> type_vecIDs;
