@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.1.1.1 2003/01/21 13:41:30 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.2 2004/02/10 14:48:59 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -30,10 +30,10 @@ ExampleWindow::ExampleWindow()
   add(m_ButtonBox);
   
   m_ButtonBox.pack_start(m_Button_File);
-  m_Button_File.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_file_clicked) );
+  m_Button_File.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_file_clicked) );
 
   m_ButtonBox.pack_start(m_Button_Folder);
-  m_Button_Folder.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_folder_clicked) );
+  m_Button_Folder.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_folder_clicked) );
 
   show_all_children();
 }
