@@ -1,4 +1,4 @@
-//$Id: helloworld.cc,v 1.1.1.1 2003/01/21 13:41:32 murrayc Exp $ -*- c++ -*-
+//$Id: helloworld.cc,v 1.2 2004/02/10 14:49:14 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -27,7 +27,7 @@ HelloWorld::HelloWorld()
 
   // When the button receives the "clicked" signal, it will call the
   // hello() method. The hello() method is defined below.
-  m_button.signal_clicked().connect(SigC::slot(*this, &HelloWorld::on_button_clicked));
+  m_button.signal_clicked().connect(sigc::mem_fun(*this, &HelloWorld::on_button_clicked));
 
   // This packs the button into the Window (a container).
   add(m_button);
