@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.9 2003/11/01 17:02:39 murrayc Exp $ */
+/* $Id: generate_defs_gtk.cc,v 1.10 2004/01/02 09:56:58 murrayc Exp $ */
 
 /* generate_defs_gtk.cc
  *
@@ -29,11 +29,12 @@ int main (int argc, char *argv[])
 
   void *const g_class_atk_no_op_object = g_type_class_ref(ATK_TYPE_NO_OP_OBJECT);
 
-  std::cout << get_defs( ATK_TYPE_HYPERLINK )
-            << get_defs( ATK_TYPE_OBJECT )
+  std::cout << get_defs( ATK_TYPE_OBJECT )
             << get_defs( ATK_TYPE_COMPONENT )
             << get_defs( ATK_TYPE_ACTION )
             << get_defs( ATK_TYPE_EDITABLE_TEXT )
+            << get_defs( ATK_TYPE_HYPERLINK )
+            << get_defs( ATK_TYPE_HYPERTEXT )
             << get_defs( ATK_TYPE_IMAGE )
             << get_defs( ATK_TYPE_SELECTION )
             << get_defs( ATK_TYPE_TABLE )
